wagtail_uplift
==============

|PyPI| |GitHub Issues|

A custom theme for Wagtail’s dashboard. Pure CSS overrides, there's no extra configuration.

Installation
------------

. code:: sh
    pip install git+https://github.com/l1f7/wagtail_uplift

Add the application to your installed apps:

. code:: python
    INSTALLED_APPS = [
        'wagtail_uplift',
        'wagtail',
    ]


.. |PyPI| image:: https://img.shields.io/pypi/v/wagtail_uplift.svg?style=flat-square
   :target: https://pypi.python.org/pypi/wagtail_uplift/
.. |GitHub Issues| image:: https://img.shields.io/github/issues/l1f7/wagtail_uplift.svg?style=flat-square
   :target: https://github.com/l1f7/wagtail_uplift/issues
